@@ -21,12 +21,14 @@ xgx_geom_pi <- function(mapping = NULL, data = NULL, percent_level = 0.95,
                         show.legend = NA,
                         inherit.aes = TRUE,
                         ...) {
-  return(list(xgx_stat_pi(mapping, data, percent_level,
-                          geom,
-                          position,
-                          fun.args,
-                          na.rm,
-                          show.legend,
-                          inherit.aes,
+  return(list(xgx_stat_pi(mapping = mapping, 
+                          data = data, 
+                          percent_level = percent_level,
+                          geom = geom,
+                          position = position,
+                          fun.args = fun.args,
+                          na.rm = na.rm,
+                          show.legend = show.legend,
+                          inherit.aes = inherit.aes,
                           ...)))
 }
