@@ -385,6 +385,11 @@ predictdf.nls <- function(model, xseq, se, level) {
       for(i in 1:length(xvec)){
         x = xvec[i]
         ret$grad[[i]] <- eval(Deriv::Deriv(form, names(pars), cache.exp = FALSE)) %>% as.list()
+        
+        if(is.null(names(ret$grad[[i]]))){
+          names(ret$grad[[i]]) <- names(pars)
+        }
+        
       }
       
       ret$grad <- dplyr::bind_rows(ret$grad) %>% as.matrix
@@ -438,7 +443,6 @@ predictdf.nls <- function(model, xseq, se, level) {
 #' @param weight weights to use for method
 #' @param n_boot number of bootstraps to perform for confidence interval calculation, default is 200
 #' 
-#' @importFrom stats predict
 #' 
 #' @exportS3Method ggplot2::predictdf
 predictdf.polr <- function(model, xseq, se, level, 
